[SCM] Samba Shared Repository - branch master updated

Jeremy Allison jra at samba.org
Fri May 1 13:53:05 MDT 2015


The branch, master has been updated
       via  4889cee Convert uint32/16/8 to _t for the last two include files in source3/include.
       via  e049943 Convert three include files from uint32/16/8 to _t types as well as the source that includes them.
       via  b79aed8 Convert all uses of uint8/16/32 to _t in nmbd and the include file.
       via  df0eeca Convert uint32/16/8 to 32_t/16_t/8_t in printing.h and all files that include it.
      from  9d7ecb9 s4: torture: Test for incorrect file size returned in the response of "FILE_SUPERSEDE Create".

https://git.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit 4889cee60eb08a436bb28f1210e826b50ede91dd
Author: Richard Sharpe <rsharpe at samba.org>
Date:   Thu Apr 30 20:16:18 2015 -0700

    Convert uint32/16/8 to _t for the last two include files in source3/include.
    
    There are still many files to touch before we can remove the #define but this
    gets the last include files in source3/includes.
    
    Signed-off-by: Richard Sharpe <rsharpe at samba.org>
    Reviewed-by: Jeremy Allson <jra at samba.org>
    
    Autobuild-User(master): Jeremy Allison <jra at samba.org>
    Autobuild-Date(master): Fri May  1 21:52:25 CEST 2015 on sn-devel-104

commit e049943eba470918d188ca7b959e36bfc2d746b1
Author: Richard Sharpe <rsharpe at samba.org>
Date:   Thu Apr 30 19:22:21 2015 -0700

    Convert three include files from uint32/16/8 to _t types as well as the source that includes them.
    
    The files that include them already seem clean.
    
    Signed-off-by: Richard Sharpe <rsharpe at samba.org>
    Reviewed-by: Jeremy Allison <jra at samba.org>

commit b79aed8592fa2a388f63098406c1f1b88d1da7eb
Author: Richard Sharpe <rsharpe at samba.org>
Date:   Wed Apr 29 20:14:34 2015 -0700

    Convert all uses of uint8/16/32 to _t in nmbd and the include file.
    
    Signed-off-by: Richard Sharpe <rsharpe at samba.org>
    Reviewed-by: Jeremy Allison <jra at samba.org>

commit df0eeca057631d406b1587af86872b209c73ee1a
Author: Richard Sharpe <rsharpe at samba.org>
Date:   Sun Apr 26 16:02:55 2015 -0700

    Convert uint32/16/8 to 32_t/16_t/8_t in printing.h and all files that include it.
    
    Signed-off-by: Richard Sharpe <rsharpe at samba.org>
    Reviewed-by: Jeremy Allison <jra at samba.org>

-----------------------------------------------------------------------

Summary of changes:
 source3/include/fake_file.h           |   2 +-
 source3/include/msdfs.h               |   8 +-
 source3/include/nameserv.h            |  12 +--
 source3/include/nt_printing.h         |  18 ++--
 source3/include/ntioctl.h             |   2 +-
 source3/include/ntquotas.h            |   2 +-
 source3/include/printing.h            |  26 +++---
 source3/libsmb/clidfs.c               |  16 ++--
 source3/modules/vfs_default.c         |  16 ++--
 source3/modules/vfs_full_audit.c      |  12 +--
 source3/modules/vfs_shadow_copy.c     |   4 +-
 source3/modules/vfs_time_audit.c      |  12 +--
 source3/nmbd/nmbd_become_dmb.c        |   4 +-
 source3/nmbd/nmbd_become_lmb.c        |   8 +-
 source3/nmbd/nmbd_browsesync.c        |   4 +-
 source3/nmbd/nmbd_elections.c         |   8 +-
 source3/nmbd/nmbd_incomingdgrams.c    |  12 +--
 source3/nmbd/nmbd_incomingrequests.c  |   4 +-
 source3/nmbd/nmbd_lmhosts.c           |   6 +-
 source3/nmbd/nmbd_logonnames.c        |   4 +-
 source3/nmbd/nmbd_mynames.c           |   4 +-
 source3/nmbd/nmbd_namelistdb.c        |   6 +-
 source3/nmbd/nmbd_nameregister.c      |  14 +--
 source3/nmbd/nmbd_packets.c           |  28 +++---
 source3/nmbd/nmbd_processlogon.c      |   6 +-
 source3/nmbd/nmbd_responserecordsdb.c |   4 +-
 source3/nmbd/nmbd_sendannounce.c      |   6 +-
 source3/nmbd/nmbd_serverlistdb.c      |  12 +--
 source3/nmbd/nmbd_subnetdb.c          |   2 +-
 source3/nmbd/nmbd_synclists.c         |   6 +-
 source3/nmbd/nmbd_winsproxy.c         |   2 +-
 source3/nmbd/nmbd_winsserver.c        |  38 ++++----
 source3/nmbd/nmbd_workgroupdb.c       |   2 +-
 source3/printing/notify.c             |  46 +++++-----
 source3/printing/nt_printing.c        |  22 ++---
 source3/printing/printing.c           | 136 ++++++++++++++--------------
 source3/smbd/fake_file.c              |   2 +-
 source3/smbd/lanman.c                 |  14 +--
 source3/smbd/nttrans.c                | 166 +++++++++++++++++-----------------
 source3/smbd/open.c                   |  62 ++++++-------
 source3/smbd/reply.c                  | 102 ++++++++++-----------
 source3/smbd/trans2.c                 | 132 +++++++++++++--------------
 source3/utils/smbcontrol.c            |   6 +-
 source3/utils/smbcquotas.c            |   4 +-
 44 files changed, 501 insertions(+), 501 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/include/fake_file.h b/source3/include/fake_file.h
index da0c35b..00ebc88 100644
--- a/source3/include/fake_file.h
+++ b/source3/include/fake_file.h
@@ -44,7 +44,7 @@ NTSTATUS open_fake_file(struct smb_request *req, connection_struct *conn,
 				uint64_t current_vuid,
 				enum FAKE_FILE_TYPE fake_file_type,
 				const struct smb_filename *smb_fname,
-				uint32 access_mask,
+				uint32_t access_mask,
 				files_struct **result);
 NTSTATUS close_fake_file(struct smb_request *req, files_struct *fsp);
 
diff --git a/source3/include/msdfs.h b/source3/include/msdfs.h
index b389229..333a840 100644
--- a/source3/include/msdfs.h
+++ b/source3/include/msdfs.h
@@ -38,15 +38,15 @@
 #define MAX_MSDFS_JUNCTIONS 256
 
 struct client_dfs_referral {
-	uint32 proximity;
-	uint32 ttl;
+	uint32_t proximity;
+	uint32_t ttl;
 	char *dfspath;
 };
 
 struct referral {
 	char *alternate_path; /* contains the path referred */
-	uint32 proximity;
-	uint32 ttl; /* how long should client cache referral */
+	uint32_t proximity;
+	uint32_t ttl; /* how long should client cache referral */
 };
 
 struct junction_map {
diff --git a/source3/include/nameserv.h b/source3/include/nameserv.h
index 378d25e..29b2d87 100644
--- a/source3/include/nameserv.h
+++ b/source3/include/nameserv.h
@@ -199,7 +199,7 @@ enum logon_state {
 struct subnet_record;
 
 struct nmb_data {
-	uint16 nb_flags;         /* Netbios flags. */
+	uint16_t nb_flags;       /* Netbios flags. */
 	int num_ips;             /* Number of ip entries. */
 	struct in_addr *ip;      /* The ip list for this name. */
 
@@ -235,7 +235,7 @@ struct browse_cache_record {
 /* used for server information: client, nameserv and ipc */
 struct server_info_struct {
 	fstring name;
-	uint32 type;
+	uint32_t type;
 	fstring comment;
 	fstring domain; /* used ONLY in ipc.c NOT namework.c */
 	bool server_added; /* used ONLY in ipc.c NOT namework.c */
@@ -289,7 +289,7 @@ struct work_record {
 	bool    RunningElection;
 	bool    needelection;
 	int     ElectionCount;
-	uint32  ElectionCriterion;
+	uint32_t  ElectionCriterion;
 
 	/* Domain master browser info. Used for efficient syncs. */
 	struct nmb_name dmb_name;
@@ -337,7 +337,7 @@ typedef void (*fail_function)(struct subnet_record *, struct response_record *,
 typedef void (*register_name_success_function)( struct subnet_record *,
                                                 struct userdata_struct *,
                                                 struct nmb_name *,
-                                                uint16,
+                                                uint16_t,
                                                 int,
                                                 struct in_addr);
 typedef void (*register_name_fail_function)( struct subnet_record *,
@@ -355,7 +355,7 @@ typedef void (*release_name_fail_function)( struct subnet_record *,
 typedef void (*refresh_name_success_function)( struct subnet_record *,
                                                struct userdata_struct *, 
                                                struct nmb_name *,
-                                               uint16,
+                                               uint16_t,
                                                int,
                                                struct in_addr);
 typedef void (*refresh_name_fail_function)( struct subnet_record *,
@@ -386,7 +386,7 @@ struct response_record {
 	struct response_record *next;
 	struct response_record *prev;
 
-	uint16 response_id;
+	uint16_t response_id;
 
 	/* Callbacks for packets received or not. */ 
 	response_function resp_fn;
diff --git a/source3/include/ntioctl.h b/source3/include/ntioctl.h
index 65bed64..f9e6dd9 100644
--- a/source3/include/ntioctl.h
+++ b/source3/include/ntioctl.h
@@ -34,7 +34,7 @@ typedef char SHADOW_COPY_LABEL[25];
 
 struct shadow_copy_data {
 	/* Total number of shadow volumes currently mounted */
-	uint32 num_volumes;
+	uint32_t num_volumes;
 	/* Concatenated list of labels */
 	SHADOW_COPY_LABEL *labels;
 };
diff --git a/source3/include/ntquotas.h b/source3/include/ntquotas.h
index cd46026..d8a0dc3 100644
--- a/source3/include/ntquotas.h
+++ b/source3/include/ntquotas.h
@@ -71,7 +71,7 @@ typedef struct _SMB_NTQUOTA_STRUCT {
 	uint64_t usedspace;
 	uint64_t softlim;
 	uint64_t hardlim;
-	uint32 qflags;
+	uint32_t qflags;
 	struct dom_sid sid;
 } SMB_NTQUOTA_STRUCT;
 
diff --git a/source3/include/printing.h b/source3/include/printing.h
index 8dd3d26..07b8678 100644
--- a/source3/include/printing.h
+++ b/source3/include/printing.h
@@ -193,31 +193,31 @@ uint16_t print_spool_rap_jobid(struct print_file_data *print_file);
 
 /* The following definitions come from printing/printing.c  */
 
-uint32 sysjob_to_jobid_pdb(struct tdb_print_db *pdb, int sysjob);
-uint32 sysjob_to_jobid(int unix_jobid);
+uint32_t sysjob_to_jobid_pdb(struct tdb_print_db *pdb, int sysjob);
+uint32_t sysjob_to_jobid(int unix_jobid);
 int jobid_to_sysjob_pdb(struct tdb_print_db *pdb, uint32_t jobid);
 bool print_notify_register_pid(int snum);
 bool print_notify_deregister_pid(int snum);
-bool print_job_exists(const char* sharename, uint32 jobid);
+bool print_job_exists(const char* sharename, uint32_t jobid);
 struct spoolss_DeviceMode *print_job_devmode(TALLOC_CTX *mem_ctx,
 					     const char *sharename,
-					     uint32 jobid);
+					     uint32_t jobid);
 bool print_job_set_name(struct tevent_context *ev,
 			struct messaging_context *msg_ctx,
-			const char *sharename, uint32 jobid, const char *name);
+			const char *sharename, uint32_t jobid, const char *name);
 bool print_job_get_name(TALLOC_CTX *mem_ctx, const char *sharename, uint32_t jobid, char **name);
 WERROR print_job_delete(const struct auth_session_info *server_info,
 			struct messaging_context *msg_ctx,
 			int snum, uint32_t jobid);
 WERROR print_job_pause(const struct auth_session_info *server_info,
 		     struct messaging_context *msg_ctx,
-		     int snum, uint32 jobid);
+		     int snum, uint32_t jobid);
 WERROR print_job_resume(const struct auth_session_info *server_info,
 		      struct messaging_context *msg_ctx,
-		      int snum, uint32 jobid);
+		      int snum, uint32_t jobid);
 ssize_t print_job_write(struct tevent_context *ev,
 			struct messaging_context *msg_ctx,
-			int snum, uint32 jobid, const char *buf, size_t size);
+			int snum, uint32_t jobid, const char *buf, size_t size);
 int print_queue_length(struct messaging_context *msg_ctx, int snum,
 		       print_status_struct *pstatus);
 WERROR print_job_start(const struct auth_session_info *server_info,
@@ -226,9 +226,9 @@ WERROR print_job_start(const struct auth_session_info *server_info,
 		       int snum, const char *docname, const char *filename,
 		       struct spoolss_DeviceMode *devmode, uint32_t *_jobid);
 void print_job_endpage(struct messaging_context *msg_ctx,
-		       int snum, uint32 jobid);
+		       int snum, uint32_t jobid);
 NTSTATUS print_job_end(struct messaging_context *msg_ctx, int snum,
-		       uint32 jobid, enum file_close_type close_type);
+		       uint32_t jobid, enum file_close_type close_type);
 int print_queue_status(struct messaging_context *msg_ctx, int snum,
 		       print_queue_struct **ppqueue,
 		       print_status_struct *status);
@@ -238,9 +238,9 @@ WERROR print_queue_resume(const struct auth_session_info *server_info,
 			  struct messaging_context *msg_ctx, int snum);
 WERROR print_queue_purge(const struct auth_session_info *server_info,
 			 struct messaging_context *msg_ctx, int snum);
-uint16 pjobid_to_rap(const char* sharename, uint32 jobid);
-bool rap_to_pjobid(uint16 rap_jobid, fstring sharename, uint32 *pjobid);
-void rap_jobid_delete(const char* sharename, uint32 jobid);
+uint16_t pjobid_to_rap(const char* sharename, uint32_t jobid);
+bool rap_to_pjobid(uint16_t rap_jobid, fstring sharename, uint32_t *pjobid);
+void rap_jobid_delete(const char* sharename, uint32_t jobid);
 bool print_backend_init(struct messaging_context *msg_ctx);
 void printing_end(void);
 
diff --git a/source3/libsmb/clidfs.c b/source3/libsmb/clidfs.c
index 434cb18..bd587bc 100644
--- a/source3/libsmb/clidfs.c
+++ b/source3/libsmb/clidfs.c
@@ -328,8 +328,8 @@ static NTSTATUS cli_cm_connect(TALLOC_CTX *ctx,
 	}
 
 	if (referring_cli && referring_cli->requested_posix_capabilities) {
-		uint16 major, minor;
-		uint32 caplow, caphigh;
+		uint16_t major, minor;
+		uint32_t caplow, caphigh;
 		status = cli_unix_extensions_version(cli, &major, &minor,
 						     &caplow, &caphigh);
 		if (NT_STATUS_IS_OK(status)) {
@@ -658,7 +658,7 @@ NTSTATUS cli_dfs_get_referral(TALLOC_CTX *ctx,
 	smb_ucs2_t *path_ucs;
 	char *consumed_path = NULL;
 	uint16_t consumed_ucs;
-	uint16 num_referrals;
+	uint16_t num_referrals;
 	struct client_dfs_referral *referrals = NULL;
 	NTSTATUS status;
 	TALLOC_CTX *frame = talloc_stackframe();
@@ -773,10 +773,10 @@ NTSTATUS cli_dfs_get_referral(TALLOC_CTX *ctx,
 	*consumed = strlen(consumed_path);
 
 	if (num_referrals != 0) {
-		uint16 ref_version;
-		uint16 ref_size;
+		uint16_t ref_version;
+		uint16_t ref_size;
 		int i;
-		uint16 node_offset;
+		uint16_t node_offset;
 
 		referrals = talloc_array(ctx, struct client_dfs_referral,
 					 num_referrals);
@@ -868,7 +868,7 @@ NTSTATUS cli_resolve_path(TALLOC_CTX *ctx,
 	char *newmount = NULL;
 	char *ppath = NULL;
 	SMB_STRUCT_STAT sbuf;
-	uint32 attributes;
+	uint32_t attributes;
 	NTSTATUS status;
 	struct smbXcli_tcon *root_tcon = NULL;
 	struct smbXcli_tcon *target_tcon = NULL;
@@ -1174,7 +1174,7 @@ bool cli_check_msdfs_proxy(TALLOC_CTX *ctx,
 	size_t consumed = 0;
 	char *fullpath = NULL;
 	bool res;
-	uint16 cnum;
+	uint16_t cnum;
 	char *newextrapath = NULL;
 	NTSTATUS status;
 	const char *remote_name;
diff --git a/source3/modules/vfs_default.c b/source3/modules/vfs_default.c
index 7d2a0e5..9b434a0 100644
--- a/source3/modules/vfs_default.c
+++ b/source3/modules/vfs_default.c
@@ -371,7 +371,7 @@ static NTSTATUS vfswrap_snap_delete(struct vfs_handle_struct *handle,
 
 /* Directory operations */
 
-static DIR *vfswrap_opendir(vfs_handle_struct *handle, const char *fname, const char *mask, uint32 attr)
+static DIR *vfswrap_opendir(vfs_handle_struct *handle, const char *fname, const char *mask, uint32_t attr)
 {
 	DIR *result;
 
@@ -384,7 +384,7 @@ static DIR *vfswrap_opendir(vfs_handle_struct *handle, const char *fname, const
 static DIR *vfswrap_fdopendir(vfs_handle_struct *handle,
 			files_struct *fsp,
 			const char *mask,
-			uint32 attr)
+			uint32_t attr)
 {
 	DIR *result;
 
@@ -1141,8 +1141,8 @@ static NTSTATUS vfswrap_fsctl(struct vfs_handle_struct *handle,
 		 */
 		struct shadow_copy_data *shadow_data = NULL;
 		bool labels = False;
-		uint32 labels_data_count = 0;
-		uint32 i;
+		uint32_t labels_data_count = 0;
+		uint32_t i;
 		char *cur_pdata = NULL;
 
 		if (max_out_len < 16) {
@@ -2029,7 +2029,7 @@ static bool vfswrap_lock(vfs_handle_struct *handle, files_struct *fsp, int op, o
 }
 
 static int vfswrap_kernel_flock(vfs_handle_struct *handle, files_struct *fsp,
-				uint32 share_mode, uint32 access_mask)
+				uint32_t share_mode, uint32_t access_mask)
 {
 	START_PROFILE(syscall_kernel_flock);
 	kernel_flock(fsp->fh->fd, share_mode, access_mask);
@@ -2334,7 +2334,7 @@ static void vfswrap_strict_unlock(struct vfs_handle_struct *handle,
 
 static NTSTATUS vfswrap_fget_nt_acl(vfs_handle_struct *handle,
 				    files_struct *fsp,
-				    uint32 security_info,
+				    uint32_t security_info,
 				    TALLOC_CTX *mem_ctx,
 				    struct security_descriptor **ppdesc)
 {
@@ -2349,7 +2349,7 @@ static NTSTATUS vfswrap_fget_nt_acl(vfs_handle_struct *handle,
 
 static NTSTATUS vfswrap_get_nt_acl(vfs_handle_struct *handle,
 				   const char *name,
-				   uint32 security_info,
+				   uint32_t security_info,
 				   TALLOC_CTX *mem_ctx,
 				   struct security_descriptor **ppdesc)
 {
@@ -2362,7 +2362,7 @@ static NTSTATUS vfswrap_get_nt_acl(vfs_handle_struct *handle,
 	return result;
 }
 
-static NTSTATUS vfswrap_fset_nt_acl(vfs_handle_struct *handle, files_struct *fsp, uint32 security_info_sent, const struct security_descriptor *psd)
+static NTSTATUS vfswrap_fset_nt_acl(vfs_handle_struct *handle, files_struct *fsp, uint32_t security_info_sent, const struct security_descriptor *psd)
 {
 	NTSTATUS result;
 
diff --git a/source3/modules/vfs_full_audit.c b/source3/modules/vfs_full_audit.c
index c8cef60..c6648d1 100644
--- a/source3/modules/vfs_full_audit.c
+++ b/source3/modules/vfs_full_audit.c
@@ -778,7 +778,7 @@ static NTSTATUS smb_full_audit_snap_delete(struct vfs_handle_struct *handle,
 }
 
 static DIR *smb_full_audit_opendir(vfs_handle_struct *handle,
-			  const char *fname, const char *mask, uint32 attr)
+			  const char *fname, const char *mask, uint32_t attr)
 {
 	DIR *result;
 
@@ -790,7 +790,7 @@ static DIR *smb_full_audit_opendir(vfs_handle_struct *handle,
 }
 
 static DIR *smb_full_audit_fdopendir(vfs_handle_struct *handle,
-			  files_struct *fsp, const char *mask, uint32 attr)
+			  files_struct *fsp, const char *mask, uint32_t attr)
 {
 	DIR *result;
 
@@ -1531,7 +1531,7 @@ static bool smb_full_audit_lock(vfs_handle_struct *handle, files_struct *fsp,
 
 static int smb_full_audit_kernel_flock(struct vfs_handle_struct *handle,
 				       struct files_struct *fsp,
-				       uint32 share_mode, uint32 access_mask)
+				       uint32_t share_mode, uint32_t access_mask)
 {
 	int result;
 
@@ -1904,7 +1904,7 @@ static NTSTATUS smb_full_audit_readdir_attr(struct vfs_handle_struct *handle,
 }
 
 static NTSTATUS smb_full_audit_fget_nt_acl(vfs_handle_struct *handle, files_struct *fsp,
-					   uint32 security_info,
+					   uint32_t security_info,
 					   TALLOC_CTX *mem_ctx,
 					   struct security_descriptor **ppdesc)
 {
@@ -1921,7 +1921,7 @@ static NTSTATUS smb_full_audit_fget_nt_acl(vfs_handle_struct *handle, files_stru
 
 static NTSTATUS smb_full_audit_get_nt_acl(vfs_handle_struct *handle,
 					  const char *name,
-					  uint32 security_info,
+					  uint32_t security_info,
 					  TALLOC_CTX *mem_ctx,
 					  struct security_descriptor **ppdesc)
 {
@@ -1937,7 +1937,7 @@ static NTSTATUS smb_full_audit_get_nt_acl(vfs_handle_struct *handle,
 }
 
 static NTSTATUS smb_full_audit_fset_nt_acl(vfs_handle_struct *handle, files_struct *fsp,
-			      uint32 security_info_sent,
+			      uint32_t security_info_sent,
 			      const struct security_descriptor *psd)
 {
 	struct vfs_full_audit_private_data *pd;
diff --git a/source3/modules/vfs_shadow_copy.c b/source3/modules/vfs_shadow_copy.c
index 7b45c2e..5c05e25 100644
--- a/source3/modules/vfs_shadow_copy.c
+++ b/source3/modules/vfs_shadow_copy.c
@@ -73,7 +73,7 @@ static bool shadow_copy_match_name(const char *name)
 	return False;
 }
 
-static DIR *shadow_copy_opendir(vfs_handle_struct *handle, const char *fname, const char *mask, uint32 attr)
+static DIR *shadow_copy_opendir(vfs_handle_struct *handle, const char *fname, const char *mask, uint32_t attr)
 {
 	shadow_copy_Dir *dirp;
 	DIR *p = SMB_VFS_NEXT_OPENDIR(handle,fname,mask,attr);
@@ -120,7 +120,7 @@ static DIR *shadow_copy_opendir(vfs_handle_struct *handle, const char *fname, co
 	return((DIR *)dirp);
 }
 
-static DIR *shadow_copy_fdopendir(vfs_handle_struct *handle, files_struct *fsp, const char *mask, uint32 attr)
+static DIR *shadow_copy_fdopendir(vfs_handle_struct *handle, files_struct *fsp, const char *mask, uint32_t attr)
 {
 	shadow_copy_Dir *dirp;
 	DIR *p = SMB_VFS_NEXT_FDOPENDIR(handle,fsp,mask,attr);
diff --git a/source3/modules/vfs_time_audit.c b/source3/modules/vfs_time_audit.c
index eebd8ce..5c43d7c 100644
--- a/source3/modules/vfs_time_audit.c
+++ b/source3/modules/vfs_time_audit.c
@@ -348,7 +348,7 @@ static NTSTATUS smb_time_audit_snap_delete(struct vfs_handle_struct *handle,
 
 static DIR *smb_time_audit_opendir(vfs_handle_struct *handle,
 				   const char *fname,
-				   const char *mask, uint32 attr)
+				   const char *mask, uint32_t attr)
 {
 	DIR *result;
 	struct timespec ts1,ts2;
@@ -368,7 +368,7 @@ static DIR *smb_time_audit_opendir(vfs_handle_struct *handle,
 
 static DIR *smb_time_audit_fdopendir(vfs_handle_struct *handle,
 					      files_struct *fsp,
-					      const char *mask, uint32 attr)
+					      const char *mask, uint32_t attr)
 {
 	DIR *result;
 	struct timespec ts1,ts2;
@@ -1326,7 +1326,7 @@ static bool smb_time_audit_lock(vfs_handle_struct *handle, files_struct *fsp,
 
 static int smb_time_audit_kernel_flock(struct vfs_handle_struct *handle,
 				       struct files_struct *fsp,
-				       uint32 share_mode, uint32 access_mask)
+				       uint32_t share_mode, uint32_t access_mask)
 {
 	int result;
 	struct timespec ts1,ts2;
@@ -1901,7 +1901,7 @@ static NTSTATUS smb_time_audit_readdir_attr(struct vfs_handle_struct *handle,
 
 static NTSTATUS smb_time_audit_fget_nt_acl(vfs_handle_struct *handle,
 					   files_struct *fsp,
-					   uint32 security_info,
+					   uint32_t security_info,
 					   TALLOC_CTX *mem_ctx,
 					   struct security_descriptor **ppdesc)
 {
@@ -1924,7 +1924,7 @@ static NTSTATUS smb_time_audit_fget_nt_acl(vfs_handle_struct *handle,
 
 static NTSTATUS smb_time_audit_get_nt_acl(vfs_handle_struct *handle,
 					  const char *name,
-					  uint32 security_info,
+					  uint32_t security_info,
 					  TALLOC_CTX *mem_ctx,
 					  struct security_descriptor **ppdesc)
 {
@@ -1947,7 +1947,7 @@ static NTSTATUS smb_time_audit_get_nt_acl(vfs_handle_struct *handle,
 
 static NTSTATUS smb_time_audit_fset_nt_acl(vfs_handle_struct *handle,
 					   files_struct *fsp,
-					   uint32 security_info_sent,
+					   uint32_t security_info_sent,
 					   const struct security_descriptor *psd)
 {
 	NTSTATUS result;


diff --git a/source3/include/nt_printing.h b/source3/include/nt_printing.h
index bfb6f8e..e253658 100644
--- a/source3/include/nt_printing.h
+++ b/source3/include/nt_printing.h
@@ -67,33 +67,33 @@
 #define VS_NE_BUF_SIZE                  4096  /* Must be > 2*VS_VERSION_INFO_SIZE */
 
 /* Notify spoolss clients that something has changed.  The
-   notification data is either stored in two uint32 values or a
+   notification data is either stored in two uint32_t values or a
    variable length array. */
 
 #define SPOOLSS_NOTIFY_MSG_UNIX_JOBID 0x0001    /* Job id is unix  */
 
 typedef struct spoolss_notify_msg {
 	fstring printer;	/* Name of printer notified */
-	uint32 type;		/* Printer or job notify */
-	uint32 field;		/* Notify field changed */
-	uint32 id;		/* Job id */
-	uint32 len;		/* Length of data, 0 for two uint32 value */
-	uint32 flags;
+	uint32_t type;		/* Printer or job notify */
+	uint32_t field;		/* Notify field changed */
+	uint32_t id;		/* Job id */
+	uint32_t len;		/* Length of data, 0 for two uint32_t value */
+	uint32_t flags;
 	union {
-		uint32 value[2];
+		uint32_t value[2];
 		char *data;
 	} notify;
 } SPOOLSS_NOTIFY_MSG;
 
 typedef struct {
 	fstring 		printername;
-	uint32			num_msgs;
+	uint32_t		num_msgs;
 	SPOOLSS_NOTIFY_MSG	*msgs;
 } SPOOLSS_NOTIFY_MSG_GROUP;
 
 typedef struct {
 	TALLOC_CTX 			*ctx;
-	uint32				num_groups;
+	uint32_t			num_groups;
 	SPOOLSS_NOTIFY_MSG_GROUP	*msg_groups;
 } SPOOLSS_NOTIFY_MSG_CTR;
 
-- 
Samba Shared Repository


More information about the samba-cvs mailing list